==> pca_b_stream-2022.5-py3-none-any.whl: pca_b_stream/flask/html/constants.py <==
# Copyright CNRS/Inria/UCA
# Contributor(s): Eric Debreuve (since 2021)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

import dominate.tags as html

from pca_b_stream.flask.session.constants import PROJECT_NAME as NAME


NAME_MEANING = "Byte Stream Representation of Piecewise-constant Array"
SHORT_DESCRIPTION = (
    "Generation of a printable byte stream representation of a piecewise-constant Numpy array, "
    "and re-creation of the array from the byte stream."
)

ABOUT = html.div(
    html.h4("Purpose"),
    html.p(SHORT_DESCRIPTION),
    #
    html.h4("Privacy"),
    html.p(
        f"""
            Uploaded inputs are stored on the server for the sole processing by {NAME}.
            All data, uploaded, intermediate and final, can be deleted manually through a dedicated button
            that appears on processing completion.
            If not deleted manually, all data are automatically deleted based on their timestamp
            by a process running several times a day.
        """
    ),
    #
    html.h4("Links"),
    html.ul(
        html.li(
            html.a(
                "Documentation",
                href="https://gitlab.inria.fr/edebreuv/pca-b-stream/-/blob/master/README.rst",
            )
        ),
        html.li(
            html.a(
                "Source code (Gitlab repository)",
                href="https://gitlab.inria.fr/edebreuv/pca-b-stream/",
            )
        ),
        html.li(
            html.a(
                "Python Package Index (PyPI) page",
                href="https://pypi.org/project/pca-b-stream/",
            )
        ),
    ),
)

MAX_IMAGE_SIZE = 256  # MB

==> pca_b_stream-2023.1-py3-none-any.whl: pca_b_stream/flask/html/constants.py <==
# Copyright CNRS/Inria/UCA
# Contributor(s): Eric Debreuve (since 2021)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

import dominate.tags as html

from pca_b_stream.flask.session.constants import PROJECT_NAME

NAME_MEANING = "Byte Stream Representation of Piecewise-constant Array"
SHORT_DESCRIPTION = (
    "Generation of a printable byte stream representation of a piecewise-constant Numpy array, "
    "and re-creation of the array from the byte stream."
)

ABOUT = html.div(
    html.h4("Purpose"),
    html.p(SHORT_DESCRIPTION),
    #
    html.h4("Privacy"),
    html.p(
        f"""
            Uploaded inputs are stored on the server for the sole processing by {PROJECT_NAME}.
            All data, uploaded, intermediate and final, can be deleted manually through a dedicated button
            that appears on processing completion.
            If not deleted manually, all data are automatically deleted based on their timestamp
            by a process running several times a day.
        """
    ),
    #
    html.h4("Links"),
    html.ul(
        html.li(
            html.a(
                "Documentation",
                href="https://gitlab.inria.fr/edebreuv/pca-b-stream/-/blob/master/README.rst",
            )
        ),
        html.li(
            html.a(
                "Source code (Gitlab repository)",
                href="https://gitlab.inria.fr/edebreuv/pca-b-stream/",
            )
        ),
        html.li(
            html.a(
                "Python Package Index (PyPI) page",
                href="https://pypi.org/project/pca-b-stream/",
            )
        ),
    ),
)

MAX_IMAGE_SIZE = 256  # MB
